@@ -29,7 +29,6 @@
 #include <glade/glade.h>
 #include <pwd.h>
 #include <unistd.h>
-#include <bonobo/bonobo-main.h>
 #include <libebook/e-book.h>
 
 #include "e-image-chooser.h"
@@ -37,13 +36,15 @@
 
 #include "capplet-util.h"
 
+#define MAX_HEIGHT 150
+#define MAX_WIDTH  150
+
 typedef struct {
 	EContact 	*contact;
 	EBook    	*book;
 	
 	GladeXML 	*dialog;
 
-	GtkWidget    	*fsel;
 	GdkScreen    	*screen;
 	GtkIconTheme 	*theme;
 
@@ -125,26 +126,22 @@ struct WidToCid ids[] = {
         {     NULL,            0                             }
 };
 
-enum
-{
-	RESPONSE_APPLY = 1,
-	RESPONSE_CLOSE
-};
 
 static void about_me_set_address_field (EContactAddress *, guint, gchar *);
 
 
 /*** Utility functions ***/
 static void
-about_me_error (GtkWidget *parent, gchar *str)
+about_me_error (GtkWindow *parent, gchar *str)
 {
-	GtkWidget *warn;
+	GtkWidget *dialog;
 	
-	warn = gtk_message_dialog_new (GTK_WINDOW (parent), 
-				       GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR,
-				       GTK_BUTTONS_OK, str);
+	dialog = gtk_message_dialog_new (parent, 
+				         GTK_DIALOG_MODAL, GTK_MESSAGE_ERROR,
+				         GTK_BUTTONS_OK, str);
 
-	g_signal_connect (warn, "response", G_CALLBACK (gtk_widget_destroy), NULL);
+	gtk_dialog_run (GTK_DIALOG (dialog));
+	gtk_widget_destroy (dialog);
 }
 
 
@@ -153,10 +150,13 @@ static void
 about_me_commit (GnomeAboutMe *me)
 {
 	EContactName *name;
-	char *fileas;
-	char *strings[4], **stringptr;
-	GError *error = NULL;
+	GError *error;
 
+	char *strings[4], **stringptr;
+	char *fileas;
+
+	name = NULL;
+	error = NULL;
 
 	if (me->create_self) {
 		if (me->username == NULL)
@@ -186,7 +186,7 @@ about_me_commit (GnomeAboutMe *me)
 		e_book_set_self (me->book, me->contact, &error);
 	} else {
 		if (e_book_commit_contact (me->book, me->contact, &error) == FALSE)
-			g_print ("There was an undeterminad error\n");
+			g_print ("There was an undetermined error\n");
 	}
 
 	me->create_self = FALSE;
@@ -229,10 +229,10 @@ about_me_focus_out (GtkWidget *widget, GdkEventFocus *event, GnomeAboutMe *me)
 		iter_end = iter_start;
 		gtk_text_iter_forward_to_end (&iter_end);
 		str = gtk_text_iter_get_text (&iter_start, &iter_end);
+	} else {
+		str = "";
 	}
 
-	str = str ? str : "";
-	
 	/* FIXME: i'm getting an empty address field in evolution */
 	if (i >= ADDRESS_HOME && i < ADDRESS_WORK) {
 		about_me_set_address_field (me->addr1, ids[i].cid, str);
@@ -255,8 +255,6 @@ about_me_focus_out (GtkWidget *widget, GdkEventFocus *event, GnomeAboutMe *me)
 	return FALSE;
 }
 
-/********************/
-
 static char *
 get_user_login (void)
 {
@@ -272,26 +270,14 @@ get_user_login (void)
  * Helpers
  */
 
-GtkWidget * 
-about_me_get_widget (GladeXML *dialog, gchar *name, gint suffix)
-{
-	GtkWidget *widget;
-	gchar *str;
-
-	str = g_strdup_printf ("%s-%d", name, suffix);
-	widget = WID(str);
-	g_free (str);
-
-	return widget;
-}
-
 static gchar *
 about_me_get_address_field (EContactAddress *addr, guint cid)
 {
-	gchar *str = NULL;
+	gchar *str;
 	
-	if (addr == NULL)
+	if (addr == NULL) {
 		return NULL;
+	}
 
 	switch (cid) {
 		case ADDRESS_STREET:
@@ -312,6 +298,9 @@ about_me_get_address_field (EContactAddress *addr, guint cid)
 		case ADDRESS_COUNTRY:
 			str = addr->country;
 			break;
+		default:
+			str = NULL;
+			break;
 	}
 
 	return str;
@@ -433,27 +422,72 @@ about_me_update_photo (GnomeAboutMe *me)
 	gchar         *file;
 	FILE	      *fp;
 
+	gchar 	      *data;
+	gsize 	       length;
+
 	dialog = me->dialog;
 
+
 	if (me->image_changed && me->have_image) {
+		GdkPixbufLoader *loader = gdk_pixbuf_loader_new ();
+		GdkPixbuf *pixbuf, *scaled;
+		int height, width;
+		gboolean do_scale = FALSE;
+		float scale;
+		
 		widget = WID ("image-chooser");
+		e_image_chooser_get_image_data (E_IMAGE_CHOOSER (widget), &data, &length);
+
+		/* Before updating the image in EDS scale it to a reasonable size
+		   so that the user doesn't get an application that does not respond
+		   or that takes 100% CPU */
+		gdk_pixbuf_loader_write (loader, (guchar *)data, length, NULL);
+		
+		pixbuf = gdk_pixbuf_loader_get_pixbuf (loader);
+		
+		if (pixbuf)
+			gdk_pixbuf_ref (pixbuf);
+			
+		gdk_pixbuf_loader_close (loader, NULL);
+
+		g_object_unref (loader);
+		
+		height = gdk_pixbuf_get_height (pixbuf);
+		width = gdk_pixbuf_get_width (pixbuf);
+		
+		if (height >= width && height > MAX_HEIGHT) {
+			scale = (float)MAX_HEIGHT/height;
+			do_scale = TRUE;
+		} else if (width > height && width > MAX_WIDTH) {
+			scale = (float)MAX_WIDTH/width;
+			do_scale = TRUE;
+		}
+
+		if (do_scale) {
+			char *scaled_data = NULL;
+			gsize scaled_length;
+			
+			scaled = gdk_pixbuf_scale_simple (pixbuf, width*scale, height*scale, GDK_INTERP_BILINEAR);
+			gdk_pixbuf_save_to_buffer (scaled, &scaled_data, &scaled_length, "png", NULL, 
+						   "compression", "9", NULL);
+			
+			g_free (data);
+			data = scaled_data;
+			length = scaled_length;
+		}
 
 		photo = g_new0 (EContactPhoto, 1);
-		e_image_chooser_get_image_data (E_IMAGE_CHOOSER (widget), &photo->data, &photo->length);
+		photo->data = data;
+		photo->length = length;
 		e_contact_set (me->contact, E_CONTACT_PHOTO, photo);
 
 		/* Save the image for GDM */
+		/* FIXME: I would have to read the default used by the gdmgreeter program */
 		file = g_strdup_printf ("%s/.face", g_get_home_dir ());
 		fp = fopen (file, "wb");
 		fwrite (photo->data, 1, photo->length, fp);
 		fclose (fp);
 
-		/* Update GDM configuration */
-		/*
-		gnome_config_set_string ("/gdmphotosetup/last/picture", file);
-		gnome_config_set_string ("/gdm/face/picture", file);
-		gnome_config_sync ();
-		*/
 		g_free (file);	
 
 		e_contact_photo_free (photo);
@@ -494,9 +528,9 @@ about_me_load_info (GnomeAboutMe *me)
 }
 
 GtkWidget *
-eab_create_image_chooser_widget(gchar *name,
-				gchar *string1, gchar *string2,
-				gint int1, gint int2)
+eab_create_image_chooser_widget (gchar *name,
+				 gchar *string1, gchar *string2,
+				 gint int1, gint int2)
 {
 	GtkWidget *w = NULL;
 
@@ -506,87 +540,56 @@ eab_create_image_chooser_widget(gchar *name,
 	return w;
 }
 
-/*
- * Functions to handle the photo changing stuff
- */
-
-static void
-image_selected (GnomeAboutMe *me)
-{
-	GtkWidget *widget;
-	GladeXML  *dialog;
-	gchar     *image;
-
-	me->have_image = TRUE;
-	me->image_changed = TRUE;
-
-	dialog = me->dialog;
-
-	widget = WID ("image-chooser");
-
-	/* obtener el fichero seleccionado */
-	image = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (me->fsel));
-	e_image_chooser_set_from_file (E_IMAGE_CHOOSER (widget), image);
-	g_free (image);
-
-	about_me_update_photo (me);
-
-	return;
-}
-
-static void
-image_cleared (GnomeAboutMe *me)
-{
-	GtkWidget *widget;
-	GladeXML  *dialog;
-
-	me->have_image = FALSE;
-	me->image_changed = TRUE;
-
-	dialog = me->dialog;
-
-	widget = WID ("image-chooser");
-
-	e_image_chooser_set_from_file (E_IMAGE_CHOOSER (widget), me->person);
-	about_me_update_photo (me);
-
-	return;
-}
-
-static void
-about_me_file_chooser_response (GtkWidget *widget, gint response, GnomeAboutMe *me)
-{
-	if (response == GTK_RESPONSE_ACCEPT)
-		image_selected (me);
-	else if (response == GTK_RESPONSE_NO)
-		image_cleared (me);
-
-	gtk_widget_hide (me->fsel);
-}
-
 static void
 about_me_image_clicked_cb (GtkWidget *button, GnomeAboutMe *me)
 {
-	char *title = _("Select Image");
-	char *noimage = _("No Image");
+	GtkWidget *chooser_dialog;
+	gint response;
+	GtkWidget *image_chooser;
+	GladeXML  *dialog;
 	
-	me->fsel = gtk_file_chooser_dialog_new (title, NULL,
-						GTK_FILE_CHOOSER_ACTION_OPEN,
-						GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-						GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
-						noimage, GTK_RESPONSE_NO,
-						NULL);
-	gtk_dialog_set_default_response (GTK_DIALOG (me->fsel), GTK_RESPONSE_ACCEPT);
+	dialog = me->dialog;
+	image_chooser = WID ("image-chooser");
 
-	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (me->fsel), g_get_home_dir ());
+	chooser_dialog = gtk_file_chooser_dialog_new (_("Select Image"), GTK_WINDOW (WID ("about-me-dialog")),
+							GTK_FILE_CHOOSER_ACTION_OPEN,
+							_("No Image"), GTK_RESPONSE_NO,
+							GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+							GTK_STOCK_OPEN, GTK_RESPONSE_ACCEPT,
+							NULL);
+	gtk_window_set_modal (GTK_WINDOW (chooser_dialog), TRUE);
+	gtk_dialog_set_default_response (GTK_DIALOG (chooser_dialog), GTK_RESPONSE_ACCEPT);
+	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (chooser_dialog), g_get_home_dir ());
 
-	g_signal_connect (me->fsel, "response",
-			  G_CALLBACK (about_me_file_chooser_response), me);
+	response=gtk_dialog_run (GTK_DIALOG (chooser_dialog));
 
-	gtk_window_present (GTK_WINDOW (me->fsel));
+	if (response == GTK_RESPONSE_ACCEPT) {
+		gchar* filename;
+
+		filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (chooser_dialog));
+		me->have_image = TRUE;
+		me->image_changed = TRUE;
+
+		e_image_chooser_set_from_file (E_IMAGE_CHOOSER (image_chooser), filename);
+		g_free (filename);
+		about_me_update_photo (me);	
+	} else if (response == GTK_RESPONSE_NO) {
+		me->have_image = FALSE;
+		me->image_changed = TRUE;
+		e_image_chooser_set_from_file (E_IMAGE_CHOOSER (image_chooser), me->person);
+		about_me_update_photo (me);
+	}
+
+	gtk_widget_destroy (chooser_dialog);
 }
 
-
+static void
+about_me_image_changed_cb (GtkWidget *widget, GnomeAboutMe *me)
+{
+	me->have_image = TRUE;
+	me->image_changed = TRUE;
+	about_me_update_photo (me);
+}
 
 /* About Me Dialog Callbacks */
 
@@ -621,6 +624,11 @@ about_me_button_clicked_cb (GtkDialog *dialog, gint response_id, GnomeAboutMe *m
 	if (response_id == GTK_RESPONSE_HELP)
 		g_print ("Help goes here");
 	else {
+		if (me->commit_timeout_id) {
+			g_source_remove (me->commit_timeout_id);
+			about_me_commit (me);
+		}
+
 		e_contact_address_free (me->addr1);
 		e_contact_address_free (me->addr2);
 
@@ -641,13 +649,14 @@ about_me_passwd_clicked_cb (GtkWidget *button, GnomeAboutMe *me)
 	GladeXML *dialog;
 	
 	dialog = me->dialog;
-	gnome_about_me_password (WID ("about-me-dialog"));
+	gnome_about_me_password (GTK_WINDOW (WID ("about-me-dialog")));
 }
 
 static void
 about_me_setup_dialog (void)
 {
 	GtkWidget    *widget;
+	GtkWidget    *main_dialog;
 	GtkIconInfo  *icon;
 	GladeXML     *dialog;
 	GError 	     *error = NULL;
@@ -661,16 +670,26 @@ about_me_setup_dialog (void)
 	dialog = glade_xml_new (GNOMECC_DATA_DIR "/interfaces/gnome-about-me.glade", 
 				"about-me-dialog", NULL);
 
+	if (dialog == NULL) {
+		g_error ("Unable to load glade file.");
+		exit (1);
+	}
+
 	me->dialog = dialog;
 
+	/* Connect the close button signal */
+	main_dialog = WID ("about-me-dialog");
+	g_signal_connect (G_OBJECT (main_dialog), "response",
+			  G_CALLBACK (about_me_button_clicked_cb), me);
+
+	gtk_window_set_resizable (GTK_WINDOW (main_dialog), FALSE);
+	capplet_set_icon (main_dialog, "user-info");
+
 	/* Setup theme details */
-	me->screen = gtk_window_get_screen (WID ("about-me-dialog"));
+	me->screen = gtk_window_get_screen (GTK_WINDOW (main_dialog));
 	me->theme = gtk_icon_theme_get_for_screen (me->screen);
 
 	icon = gtk_icon_theme_lookup_icon (me->theme, "stock_person", 80, 0);
-	if (icon == NULL) {
-		g_print ("Icon not found\n");
-	}
 
 	me->person = g_strdup (gtk_icon_info_get_filename (icon));
 
@@ -678,7 +697,7 @@ about_me_setup_dialog (void)
 
 	g_signal_connect_object (me->theme, "changed",
 				 G_CALLBACK (about_me_icon_theme_changed),
-				 GTK_WIDGET (WID ("about-me-dialog")),
+				 main_dialog,
 				 G_CONNECT_SWAPPED);
 
 	/* Get the self contact */
@@ -686,18 +705,21 @@ about_me_setup_dialog (void)
 		me->create_self = TRUE;
 		
 		me->contact = e_contact_new ();
-		g_print ("%s\n", error->message);
 
+		g_warning ("%s\n", error->message);
 		g_clear_error (&error);
 
 		if (me->book == NULL) {
 			me->book = e_book_new_system_addressbook (&error);
-			if (me->book == NULL)
-				g_print ("error message: %s\n", error->message);
+			if (me->book == NULL || error != NULL) {
+				g_error ("%s\n", error->message);
+				g_clear_error (&error);
+			}
 
 			if (e_book_open (me->book, FALSE, NULL) == FALSE) {
-				about_me_error (WID ("about-me-dialog"), 
+				about_me_error (GTK_WINDOW (main_dialog), 
 						_("Unable to open address book"));
+				g_clear_error (&error);
 			}
 		} 
 	}
@@ -707,7 +729,7 @@ about_me_setup_dialog (void)
 	setpwent ();
 	pwent = getpwnam (user);
 	if (pwent == NULL) {
-		about_me_error (WID ("about-me-dialog"), 
+		about_me_error (GTK_WINDOW (WID ("about-me-dialog")), 
 				_("Unknown login ID, the user database might be corrupted"));
 		return ;
 	}
@@ -738,16 +760,15 @@ about_me_setup_dialog (void)
 	widget = WID ("login");
 	gtk_label_set_text (GTK_LABEL (widget), user);
 
-	widget = WID ("about-me-dialog");
 	if (tok[0] == NULL || strlen (tok[0]) == 0) {
-		str = g_strdup_printf ("About %s", user);
+		str = g_strdup_printf (_("About %s"), user);
 	} else {
-		str = g_strdup_printf ("About %s", tok[0]);
+		str = g_strdup_printf (_("About %s"), tok[0]);
 	}
-	gtk_window_set_title (GTK_WINDOW (widget), str);
+	gtk_window_set_title (GTK_WINDOW (main_dialog), str);
 	g_free (str);
 
-	widget = WID("password");
+	widget = WID ("password");
 	g_signal_connect (G_OBJECT (widget), "clicked",
 			  G_CALLBACK (about_me_passwd_clicked_cb), me);
 
@@ -755,19 +776,13 @@ about_me_setup_dialog (void)
 	g_signal_connect (G_OBJECT (widget), "clicked",
 			  G_CALLBACK (about_me_image_clicked_cb), me);
 
+	widget = WID ("image-chooser");
+	g_signal_connect (G_OBJECT (widget), "changed",
+			  G_CALLBACK (about_me_image_changed_cb), me);
+
 	about_me_load_info (me);
 
-	/* Connect the close button signal */
-	widget = WID ("about-me-dialog");
-	g_signal_connect (G_OBJECT (widget), "response",
-			  G_CALLBACK (about_me_button_clicked_cb), me);
-
-	/* TODO: Set dialog icon */
-	gtk_window_set_resizable (GTK_WINDOW (widget), FALSE);
-
-	capplet_set_icon (widget, "gnome-about-me.png");
-
-	gtk_widget_show_all (widget);
+	gtk_widget_show_all (main_dialog);
 }
 
 int
@@ -782,9 +797,6 @@ main (int argc, char **argv)
 		GNOME_PARAM_APP_DATADIR, GNOMECC_DATA_DIR,
 		NULL);
 
-	if (bonobo_init (&argc, argv) == FALSE)
-		g_error ("Could not initialize Bonobo");
-
 	about_me_setup_dialog ();
 	gtk_main ();
 
